# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS & White Box as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "wbel"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorlib: %global perl_vendorlib %(eval "`perl -V:installvendorlib`"; echo $installvendorlib)}

# Perl::Critic not available prior to FC-5 and Perl 5.8.8
%global have_perl_critic %(perl -e 'print (($^V and $^V ge 5.8.8) ? 1 : 0);')

# We need to tweak the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'printf "%d\\n", $Test::More::VERSION < 0.88 ? 1 : 0;' 2>/dev/null || echo 0)

# Pick up the right dictionary for the spell check
%if %(perl -e 'print (($^V and $^V ge 5.10.0) ? 1 : 0);')
%global speller hunspell
%else
%global speller aspell
%endif

Name:		perl-MooseX-GlobRef
Version:	0.0701
Release:	3.%{__distinit}%{__distvers}
Summary:	Store a Moose object in glob reference
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/MooseX-GlobRef/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DE/DEXTER/MooseX-GlobRef-%{version}.tar.gz
Source1:	C0B10A5B.pub
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Moose) >= 0.94
BuildRequires:	perl(parent)
BuildRequires:	perl(Test::Assert)
BuildRequires:	perl(Test::Unit::Lite) >= 0.12

# Release test requirements
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
%if %{have_perl_critic}
BuildRequires:	perl(Test::Perl::Critic)
%endif
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Pod::Coverage)
BuildRequires:	perl(Test::Signature)
BuildRequires:	perl(Test::Spelling)
%if %(perl -e 'print (($] >= 5.008001) ? 1 : 0)')
BuildRequires:	%{speller}-en
%else
BuildRequires:	%{speller}-en-gb
%endif

Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Obsoletes:	perl-MooseX-GlobRef-Object < %{version}-%{release}
Provides:	perl-MooseX-GlobRef-Object = %{version}-%{release}

%description
This meta-policy allows to store Moose object in glob reference or file
handle. The class attributes will be stored in anonymous hash associated
with glob reference. It allows to create a Moose version of IO::Handle.

%prep
%setup -q -c -n MooseX-GlobRef

# Copy up documentation for convenience with %%doc
cp -a MooseX-GlobRef-%{version}/{Changes,eg,Incompatibilities,LICENSE,README} .

# Drop exec bits and avoid doc-file dependencies
chmod -c -x eg/*

# Create a GPG directory for testing, to avoid using ~/.gnupg
mkdir --mode=0700 gnupghome
GNUPGHOME=$(pwd)/gnupghome gpg --import %{SOURCE1}

%build
cd MooseX-GlobRef-%{version}
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}
cd -

%install
rm -rf %{buildroot}
make -C MooseX-GlobRef-%{version} pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -depth -type d -exec rmdir {} ';' 2>/dev/null
%{_fixperms} %{buildroot}

%check
export GNUPGHOME=$(pwd)/gnupghome
cd MooseX-GlobRef-%{version}

# === MAIN TEST SUITE === #
make test

# ===  RELEASE TESTS  === #
RELEASE_TESTS="$(echo xt/*.t | sed 's|xt/copyright.t||')"
# Don't run the copyright test as it will fail after the year of module release
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/copyright.t||')"
# Don't run the Perl::Critic test if we don't have Test::Perl::Critic
%if !%{have_perl_critic}
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/perlcritic.t||')"
%endif
# Changes test needs tweaking if we don't have Test::More >= 0.88,
# but don't do it yet as it would cause the signature test to fail
%if %{old_test_more}
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/check_changes.t||')"
%endif
make test TEST_FILES="$RELEASE_TESTS"
# Now try the Changes test if we didn't run it before
%if %{old_test_more}
sed -e 's|^use Test::CheckChanges;|use Test::More tests => 1;\n&|' xt/check_changes.t > xt/check_changes_compat.t
make test TEST_FILES=xt/check_changes_compat.t
%endif

cd -

%files
%defattr(-,root,root,-)
%doc Changes Incompatibilities LICENSE README eg/
%{perl_vendorlib}/MooseX/
%{_mandir}/man3/MooseX::GlobRef.3pm*
%{_mandir}/man3/MooseX::GlobRef::Object.3pm*
%{_mandir}/man3/MooseX::GlobRef::Role::Meta::Instance.3pm*
%{_mandir}/man3/MooseX::GlobRef::Role::Object.3pm*

%changelog
* Mon May  9 2011 Paul Howarth <paul@city-fan.org> - 0.0701-3
- Import from Fedora

* Mon Mar 14 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.0701-2
- Remove obsoletes -> causing conflicts

* Mon Mar  7 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.0701-1
- Rename package to correct name

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0701-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec 09 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.0701-1
- Upstream update (Fix FTBFS: BZ 660747)
- Remove requires-filter, adjust BRs

* Thu May 18 2010 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.07-5
- Fix build directory
- Reflect build directory having changed

* Mon May 03 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.07-4
- Mass rebuild with perl-5.12.0

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 0.07-3
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.07-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Jun 08 2009 Chris Weyl <cweyl@alumni.drew.edu> 0.07-1
- Auto-update to 0.07 (by cpan-spec-update 0.01)
- Altered br on perl(Test::Unit::Lite) (0.11 => 0.12)

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.06-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 18 2009 Allisson Azevedo <allisson@gmail.com> 0.06-1
- Update to 0.06
- Added filter requires

* Thu Jan 29 2009 Allisson Azevedo <allisson@gmail.com> 0.04-1
- Initial rpm release
